#!/bin/bash

echo "repo_name,visibility,num_workflows,pull_request_target_found,workflow_path"

gh repo list $1 --limit 3000 --json nameWithOwner | jq -r '.[].nameWithOwner' | while read repo; do
   visibility=$(gh api repos/$repo --jq '.visibility' 2>/dev/null || echo "{}")
   
   if [[ $visibility == "public" ]]; then
      WORKFLOWS=$(gh api repos/$repo/actions/workflows)
      WORKFLOW_COUNT=$(echo $WORKFLOWS | jq -r '.total_count')

      if [[ $WORKFLOW_COUNT -gt 0 ]]; then
         WORKFLOW_PATHS=$(echo "$WORKFLOWS" | jq -r '.workflows[].path')
         IDENTIFIED_PATH=""
         FOUND=false
         ERROR=false
         
         for i in $(echo "$WORKFLOW_PATHS"); do
            CONTENT=$(gh api repos/$repo/contents/$i 2>/dev/null || echo "not_found")
            
            if echo "$CONTENT" | grep -q "not_found"; then
               ERROR=true
            fi
            
            ENCODED_CONTENT=$(echo $CONTENT | jq -r '.content')
            DECODED_CONTENT=$(echo $ENCODED_CONTENT | base64 --decode)
            
            if echo "$DECODED_CONTENT" | grep -q "pull_request_target"; then
               IDENTIFIED_PATH+="$i,"
               FOUND="true"
            fi
         done
      
         IDENTIFIED_PATH="${IDENTIFIED_PATH%,}"
         
         if [[ $ERROR == true ]]; then
            echo "$repo,$visibility,$WORKFLOW_COUNT,ERROR,$IDENTIFIED_PATH"
         else
            echo "$repo,$visibility,$WORKFLOW_COUNT,$FOUND,$IDENTIFIED_PATH"
         fi
      else
         echo "$repo,$visibility,0,false,nil"
      fi
   fi
done

